@@ -313,7 +313,7 @@ class Runnable:
         raise ValueError('Unsupported kind of runnable: %s' % self.kind)
 
 
-class BaseRunner(metaclass=abc.ABCMeta):
+class BaseRunner(abc.ABC):
     """
     Base interface for a Runner
     """
@@ -662,7 +662,7 @@ class Task:
     """
 
     def __init__(self, runnable, identifier=None, status_uris=None,
-                 known_runners=None):
+                 known_runners=None, category='test'):
         """Instantiates a new Task.
 
         :param runnable: the "description" of what the task should run.
@@ -679,9 +679,14 @@ class Task:
         :type status_uri: list
         :param known_runners: a mapping of runnable kinds to runners.
         :type known_runners: dict
+        :param category: category of this task. Defaults to 'test'.
+        :type category: str
         """
         self.runnable = runnable
         self.identifier = identifier or str(uuid1())
+        #: Category of the task.  If the category is not "test", it
+        #: will not be accounted for on a Job's test results.
+        self.category = category
         self.status_services = []
         if status_uris is not None:
             for status_uri in status_uris:
@@ -689,13 +694,16 @@ class Task:
         if known_runners is None:
             known_runners = {}
         self.known_runners = known_runners
+        self.dependencies = set()
         self.spawn_handle = None
         self.output_dir = None
         self.metadata = {}
 
     def __repr__(self):
-        fmt = '<Task identifier="{}" runnable="{}" status_services="{}"'
-        return fmt.format(self.identifier, self.runnable, self.status_services)
+        fmt = ('<Task identifier="{}" runnable="{}" dependencies="{}"'
+               ' status_services="{}"')
+        return fmt.format(self.identifier, self.runnable, self.dependencies,
+                          self.status_services)
 
     def are_requirements_available(self, runners_registry=None):
         """Verifies if requirements needed to run this task are available.
