@@ -325,7 +325,7 @@ class Settings:
         self._config_path_local = os.path.join(self._config_dir_local,
                                                config_file_name)
 
-    def add_argparser_to_option(self, namespace, parser, long_arg,
+    def add_argparser_to_option(self, namespace, parser, long_arg=None,
                                 short_arg=None, positional_arg=False,
                                 choices=None, nargs=None, metavar=None,
                                 required=None, action=None,
@@ -384,6 +384,11 @@ class Settings:
             This is useful when the same option is available on different
             commands, such as "avocado run" or "avocado list".
         """
+        if not any([long_arg, short_arg, positional_arg]):
+            raise SettingsError("To add an argument parser to an option, it "
+                                "needs to have a long argument, a short "
+                                "argument or be a positional argument")
+
         option = None
         try:
             option = self._namespaces[namespace]
@@ -458,8 +463,13 @@ class Settings:
         """
         for namespace, value in arg_parse_config.items():
             # This check is important! For argparse when an option is
-            # not passed will return None. We need to update only the
+            # not passed will return None, except for positional arguments
+            # which will be an empty list.  We need to update only the
             # options that the user has specified.
+            config_option = self._namespaces.get(namespace, None)
+            positional = getattr(config_option, 'positional_arg', False)
+            if (positional and value == []):
+                continue
             if value is not None:
                 if namespace in self._namespaces:
                     self.update_option(namespace, value)
