@@ -29,7 +29,7 @@ import select
 import threading
 
 
-class BaseDrainer(metaclass=abc.ABCMeta):
+class BaseDrainer(abc.ABC):
 
     """
     Base drainer, doesn't provide complete functionality to be useful.
