@@ -16,9 +16,9 @@ from avocado.core import exit_codes
 from avocado.utils import astring, genio
 from avocado.utils import path as utils_path
 from avocado.utils import process, script
-
-from .. import (AVOCADO, BASEDIR, TestCaseTmpDir, python_module_available,
-                skipOnLevelsInferiorThan, temp_dir_prefix)
+from selftests.utils import (AVOCADO, BASEDIR, TestCaseTmpDir,
+                             python_module_available, skipOnLevelsInferiorThan,
+                             skipUnlessPathExists, temp_dir_prefix)
 
 try:
     import xmlschema
@@ -229,8 +229,8 @@ class RunnerOperationTest(TestCaseTmpDir):
         result = process.run(cmd_line, ignore_status=True)
         self.assertIn(b"Unable to resolve reference(s) 'badtest.py', 'badtest2.py'",
                       result.stderr)
-        self.assertEqual(b'', result.stdout)
-        expected_rc = exit_codes.AVOCADO_JOB_FAIL
+        self.assertIn(b'Suite is empty. There is no tests to run.', result.stderr)
+        expected_rc = exit_codes.AVOCADO_FAIL
         self.assertEqual(result.exit_status, expected_rc,
                          "Avocado did not return rc %d:\n%s" % (expected_rc, result))
 
@@ -942,6 +942,29 @@ class RunnerSimpleTestStatus(TestCaseTmpDir):
         self.config_file.remove()
 
 
+class RunnerReferenceFromConfig(TestCaseTmpDir):
+
+    def setUp(self):
+        super(RunnerReferenceFromConfig, self).setUp()
+        self.config_file = script.TemporaryScript('avocado.conf',
+                                                  "[run]\n"
+                                                  "references = ['/bin/true']\n")
+        self.config_file.save()
+
+    @skipUnlessPathExists('/bin/true')
+    def test(self):
+        cmd_line = '%s --config %s run --job-results-dir %s --disable-sysinfo'
+        cmd_line %= (AVOCADO, self.config_file.path, self.tmpdir.name)
+        result = process.run(cmd_line, ignore_status=True)
+        expected_rc = exit_codes.AVOCADO_ALL_OK
+        self.assertEqual(result.exit_status, expected_rc,
+                         "Avocado did not return rc %d:\n%s" % (expected_rc, result))
+
+    def tearDown(self):
+        super(RunnerReferenceFromConfig, self).tearDown()
+        self.config_file.remove()
+
+
 class RunnerSimpleTestFailureFields(TestCaseTmpDir):
 
     def setUp(self):
