@@ -7,8 +7,7 @@ from avocado.core import data_dir, exit_codes, job, nrunner, test
 from avocado.core.exceptions import JobBaseException
 from avocado.core.suite import TestSuite, TestSuiteStatus
 from avocado.utils import path as utils_path
-
-from .. import setup_avocado_loggers, temp_dir_prefix
+from selftests.utils import setup_avocado_loggers, temp_dir_prefix
 
 setup_avocado_loggers()
 
@@ -36,7 +35,6 @@ class JobTest(unittest.TestCase):
     def test_job_empty_suite(self):
         config = {'job.output.loglevel': 'DEBUG',
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'core.show': ['none']}
         self.job = job.Job(config)
         # Job without setup called
@@ -78,7 +76,6 @@ class JobTest(unittest.TestCase):
 
     def test_two_jobs(self):
         config = {'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'core.show': ['none']}
         with job.Job(config) as self.job, job.Job(config) as job2:
             job1 = self.job
@@ -115,7 +112,6 @@ class JobTest(unittest.TestCase):
 
     def test_job_create_test_suite_empty(self):
         config = {'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'core.show': ['none']}
         self.job = job.Job(config)
         self.job.setup()
@@ -126,7 +122,6 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found}
         self.job = job.Job.from_config(config)
         self.job.setup()
@@ -150,7 +145,6 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found}
         self.job = JobFilterTime.from_config(config)
         self.job.setup()
@@ -164,7 +158,6 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates(['true'])
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found}
         self.job = job.Job.from_config(config)
         self.job.setup()
@@ -180,7 +173,6 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found}
         self.job = JobLogPost(config)
         self.job.setup()
@@ -218,7 +210,6 @@ class JobTest(unittest.TestCase):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'core.show': ['none'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found}
         self.job = JobFilterLog.from_config(config)
         self.job.setup()
@@ -231,8 +222,7 @@ class JobTest(unittest.TestCase):
 
     def test_job_run_account_time(self):
         config = {'core.show': ['none'],
-                  'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': []}
+                  'run.results_dir': self.tmpdir.name}
         self.job = job.Job(config)
         self.job.setup()
         # temporarily disable logging on console
@@ -245,8 +235,7 @@ class JobTest(unittest.TestCase):
 
     def test_job_self_account_time(self):
         config = {'core.show': ['none'],
-                  'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': []}
+                  'run.results_dir': self.tmpdir.name}
         self.job = job.Job(config)
         self.job.setup()
         self.job.time_start = 10.0
@@ -274,7 +263,6 @@ class JobTest(unittest.TestCase):
 
     def test_job_dryrun_no_unique_job_id(self):
         config = {'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.dry_run.enabled': True,
                   'core.show': ['none']}
         self.job = job.Job(config)
@@ -282,8 +270,7 @@ class JobTest(unittest.TestCase):
         self.assertIsNotNone(self.job.config.get('run.unique_job_id'))
 
     def test_job_no_base_logdir(self):
-        config = {'core.show': ['none'],
-                  'run.store_logging_stream': []}
+        config = {'core.show': ['none']}
         with unittest.mock.patch('avocado.core.job.data_dir.get_logs_dir',
                                  return_value=self.tmpdir.name):
             self.job = job.Job(config)
@@ -320,7 +307,6 @@ class JobTest(unittest.TestCase):
 
     def test_job_dryrun_no_base_logdir(self):
         config = {'core.show': ['none'],
-                  'run.store_logging_stream': [],
                   'run.dry_run.enabled': True}
         self.job = job.Job(config)
         with self.job:
@@ -331,7 +317,6 @@ class JobTest(unittest.TestCase):
     def test_job_make_test_suite_resolver(self):
         simple_tests_found = self._find_simple_test_candidates()
         config = {'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.references': simple_tests_found,
                   'run.test_runner': 'nrunner',
                   'core.show': ['none']}
@@ -344,7 +329,6 @@ class JobTest(unittest.TestCase):
     def test_job_get_failed_tests(self):
         config = {'run.references': ['/bin/true', '/bin/false'],
                   'run.results_dir': self.tmpdir.name,
-                  'run.store_logging_stream': [],
                   'run.dry_run.enabled': True,
                   'core.show': ['none']}
         suite = TestSuite.from_config(config)
